dirs_fallback_home

Function dirs_fallback_home 

pub(crate) fn dirs_fallback_home() -> PathBuf
Home dir without depending on dirs for THIS specific lookup. Kept to avoid a dirs dep cycle from log() — log() is called from data_dir::resolve_paths via failure paths, and we want it to work even if dirs itself is mid-failure.