PendingHwnd

Struct PendingHwnd 

pub struct PendingHwnd {
    pub class_name: String,
    pub title: String,
    pub label_hint: Option<String>,
    pub arrived_at_ms: u64,
}
Phase B.9.1 — transient HWND record held until the reducer can link it to a WindowMirror. See State::pending_hwnds.

Fields

class_name: Stringtitle: Stringlabel_hint: Option<String>arrived_at_ms: u64

Milliseconds-since-launcher-start when the ReportHwndOpened arrived. Used to age out pending entries — if we still have it when a different event arrives that should have caused reconciliation, classify as HwndWithoutBrowser.